summaryrefslogtreecommitdiffstats
path: root/src/host/layer23/src/mobile
diff options
context:
space:
mode:
authorVadim Yanitskiy <vyanitskiy@sysmocom.de>2024-01-13 07:10:36 +0700
committerVadim Yanitskiy <vyanitskiy@sysmocom.de>2024-01-18 03:54:15 +0700
commit0829246a2219478ece6def0736279d5d828aa7d2 (patch)
tree4ecbcdace75a5d127a25147dcfe7b7188b21ff17 /src/host/layer23/src/mobile
parent129d0ea8024817193a0180c487e3394fbb6c7c3d (diff)
mobile: rename tch_send_voice_{msg,frame}() functions
These functions can also be used for sending data frames (CSD). Change-Id: Ib55b4405847f2efb583f3a379ff4b6929d6d6c5b Related: OS#4396
Diffstat (limited to 'src/host/layer23/src/mobile')
-rw-r--r--src/host/layer23/src/mobile/gapk_io.c2
-rw-r--r--src/host/layer23/src/mobile/gsm48_cc.c2
-rw-r--r--src/host/layer23/src/mobile/tch.c10
3 files changed, 7 insertions, 7 deletions
diff --git a/src/host/layer23/src/mobile/gapk_io.c b/src/host/layer23/src/mobile/gapk_io.c
index 3dab46df..4699bae5 100644
--- a/src/host/layer23/src/mobile/gapk_io.c
+++ b/src/host/layer23/src/mobile/gapk_io.c
@@ -550,7 +550,7 @@ int gapk_io_serve_ms(struct osmocom_ms *ms, struct gapk_io_state *state)
&state->tch_ul_fb_len);
/* Push a voice frame to the lower layers */
- tch_send_voice_msg(ms, tch_msg);
+ tch_send_msg(ms, tch_msg);
work |= 1;
}
diff --git a/src/host/layer23/src/mobile/gsm48_cc.c b/src/host/layer23/src/mobile/gsm48_cc.c
index c253cb6d..94b81cb0 100644
--- a/src/host/layer23/src/mobile/gsm48_cc.c
+++ b/src/host/layer23/src/mobile/gsm48_cc.c
@@ -2045,7 +2045,7 @@ int mncc_tx_to_cc(void *inst, int msg_type, void *arg)
case GSM_TCHH_FRAME:
case GSM_TCH_FRAME_AMR:
case GSM_BAD_FRAME:
- return tch_send_voice_frame(ms, arg);
+ return tch_send_mncc_frame(ms, arg);
case MNCC_LCHAN_MODIFY:
return 0;
case MNCC_FRAME_RECV:
diff --git a/src/host/layer23/src/mobile/tch.c b/src/host/layer23/src/mobile/tch.c
index 0b9142e3..adeaad5a 100644
--- a/src/host/layer23/src/mobile/tch.c
+++ b/src/host/layer23/src/mobile/tch.c
@@ -86,7 +86,7 @@ static int tch_recv_voice(struct osmocom_ms *ms, struct msgb *msg)
/* Remove the DL info header */
msgb_pull_to_l2(msg);
/* Send voice frame back */
- return tch_send_voice_msg(ms, msg);
+ return tch_send_msg(ms, msg);
case TCH_VOICE_IOH_MNCC_SOCK:
return tch_forward_mncc(ms, msg);
case TCH_VOICE_IOH_GAPK:
@@ -127,14 +127,14 @@ static int tch_recv_cb(struct osmocom_ms *ms, struct msgb *msg)
}
/* Send an Uplink voice frame to the lower layers */
-int tch_send_voice_msg(struct osmocom_ms *ms, struct msgb *msg)
+int tch_send_msg(struct osmocom_ms *ms, struct msgb *msg)
{
/* Forward to RR */
return gsm48_rr_tx_traffic(ms, msg);
}
-/* tch_send_voice_msg() wrapper accepting an MNCC structure */
-int tch_send_voice_frame(struct osmocom_ms *ms, const struct gsm_data_frame *frame)
+/* tch_send_msg() wrapper accepting an MNCC structure */
+int tch_send_mncc_frame(struct osmocom_ms *ms, const struct gsm_data_frame *frame)
{
struct msgb *nmsg;
int len;
@@ -163,7 +163,7 @@ int tch_send_voice_frame(struct osmocom_ms *ms, const struct gsm_data_frame *fra
nmsg->l2h = msgb_put(nmsg, len);
memcpy(nmsg->l2h, frame->data, len);
- return tch_send_voice_msg(ms, nmsg);
+ return tch_send_msg(ms, nmsg);
}
int tch_serve_ms(struct osmocom_ms *ms)